==> heptapod-rails-0.32.1.tar.gz: heptapod-rails-0.32.1/.gitlab/issue_templates/Heptapod Simplest Release.md <==
<!-- Use this template only for releases that satisfy the following
criteria:

- No GitLab Shell / Heptapod Shell version change
- No change in Python dependencies (py-heptapod, HGitaly)

If these conditions are not fulfilled, please use the `Heptapod Release`
template.

A typical use case for this simplified template is to merge and release
a GitLab patch release that does not change `GITLAB_SHELL_VERSION`,
without adding any change in Heptapod specific code to the release.

-->

### Information about the release

#### Relevant series

<!--

Either `default`, `stable` or `oldstable`.

-->

#### Main reason driving the release

<!---

It can be interesting to state what was important enough to trigger
the release.

One does not need to repeat the changelog, just a few
words, can be wording such as "new upstream GitLab version"
or "first version with xx feature" or "stated goals for %"some milestone"
reached".
--->

### Task list

- Omnibus

  + [ ] merge stabler branches into the relevant branch if needed
  + [ ] if new upstream GitLab version, merge the corresponding CE tag,
    typically `x+y+z+ce.0` into the relevant branch. Leave as draft but **not
    in a topic**, commit and push

- Rails application

  The release branch is e.g., `heptapod-0-20` while the development branch
  is `heptapod`, `heptapod-stable` or `heptapod-oldstable`.

  + [ ] merge stabler development branches into the development branch
    (pipelines not really needed).
  + [ ] start a topic from the head of the release branch (e.g, from `heptapod-0-20`)
  + [ ] merge the development branch into the release branch if needed. Commit.
  + [ ] Merge new upstream GitLab version if needed. Commit.
  + [ ] fill in [HEPTAPOD_CHANGELOG](HEPTAPOD_CHANGELOG.md)
    Be sure to include the changes related to the stabler branches. If needed
    copy them from the stabler *release* branches, as these won't get merged.
  + [ ] set HEPTAPOD_VERSION
  + [ ] commit the changes in version files, push the topic and create a Merge
        Request targeting the release branch, with automatic merge upon
        pipeline completion (estimated time between 40 and 90 minutes
        depending on whether there is a GitLab upstream update)
  + [ ] In case of GitLab upstream update, check that the pipeline
        contains the `gitlab-prebuilds` job.
  + [ ] once the topic is published by CI, pull
  + [ ] create a tag on the release branch head **without a topic** (run
    `hg topic --clear if needed` before)
  + [ ] push the tag, don't publish it yet. The tag pipeline will push the
    source tarball to download.h.n and push a commit to reference it and
    a tag in Omnibus. The resulting pipeline in Omnibus will build the
    package for Ubuntu, then the Docker image, then trigger a full run
    of the functional tests on it, as a pipeline on heptapod-tests.
  + Docker image:
    - [ ] double check that the heptapod-tests CI jobs did run for
      the image built in the Omnibus pipeline.
    - [ ] retrieve the image built by the Omnibus pipeline from registry.h.n,
      retag it as `octobus/heptapod:x.y.z` and `octobus/heptapod:latest`
    - [ ] Docker push for those two image tags.

### Finalisations

- [ ] announce the release at least on Twitter and Mastodon
- [ ] publish the changesets in all repositories made during the process (don't
  forget Omnibus)
- [ ] Create group milestone for next point release, move all remaining issues
  bearing the milestone of this release to it.
- [ ] Close milestone for this release.


/label ~Release

==> heptapod-rails-0.36.2.tar.gz: heptapod-rails-0.36.2/.gitlab/issue_templates/Heptapod Simplest Release.md <==
<!-- Use this template only for releases that satisfy the following
criteria:

- No GitLab Shell / Heptapod Shell version change
- No change in Python dependencies (py-heptapod, HGitaly)

If these conditions are not fulfilled, please use the `Heptapod Release`
template.

A typical use case for this simplified template is to merge and release
a GitLab patch release that does not change `GITLAB_SHELL_VERSION`,
without adding any change in Heptapod specific code to the release.

-->

### Information about the release

#### Relevant series

<!--

Either `default`, `stable` or `oldstable`.

-->

#### Main reason driving the release

<!---

It can be interesting to state what was important enough to trigger
the release.

One does not need to repeat the changelog, just a few
words, can be wording such as "new upstream GitLab version"
or "first version with xx feature" or "stated goals for %"some milestone"
reached".
--->

### Task list

- Omnibus

  + [ ] merge stabler branches into the relevant branch if needed
  + [ ] if new upstream GitLab version, merge the corresponding CE tag,
    typically `x+y+z+ce.0` into the relevant branch. Leave as draft but **not
    in a topic**, commit and push

- Rails application

  The release branch is e.g., `heptapod-0-20` while the development branch
  is `heptapod`, `heptapod-stable` or `heptapod-oldstable`.

  + [ ] merge stabler development branches into the development branch
    (pipelines not really needed).
  + [ ] start a topic from the head of the release branch (e.g, from `heptapod-0-20`)
  + [ ] merge the development branch into the release branch if needed. Commit.
  + [ ] Merge new upstream GitLab version if needed. Commit.
  + [ ] fill in [HEPTAPOD_CHANGELOG](HEPTAPOD_CHANGELOG.md)
    Be sure to include the changes related to the stabler branches. If needed
    copy them from the stabler *release* branches, as these won't get merged.
  + [ ] set HEPTAPOD_VERSION
  + [ ] commit the changes in version files, push the topic and create a Merge
        Request targeting the release branch, with automatic merge upon
        pipeline completion (estimated time between 40 and 90 minutes
        depending on whether there is a GitLab upstream update)
  + [ ] In case of GitLab upstream update, check that the pipeline
        contains the `gitlab-prebuilds` job.
  + [ ] once the topic is published by CI, pull
  + [ ] create a tag on the release branch head **without a topic** (run
    `hg topic --clear if needed` before)
  + [ ] push the tag, don't publish it yet. The tag pipeline will push the
    source tarball to download.h.n and push a commit to reference it and
    a tag in Omnibus. The resulting pipeline in Omnibus will build the
    package for Ubuntu, then the Docker image, then trigger a full run
    of the functional tests on it, as a pipeline on heptapod-tests.
  + Docker image:
    - [ ] take note of the Docker image ID that the heptapod-tests CI jobs
          ran for
    - [ ] retrieve the image built in the Omnibus pipeline, checking the
          Mercurial tag and the Docker image ID, and push it to Docker Hub,
          using the utility in heptapod/heptapod-docker>. Example:

          ```
          ~/heptapod/docker $ ./registry-pull-heptapod-push-docker \
          --push \
          --verify-hg-tag heptapod-0.32.1-1 \
          --expected-image-id sha256:0e976fdfa6733d4298025cd0b98ae36384863c8dd8d60ac7f9f979bb5d05b259
          ```
    - [ ] retag the image as as `octobus/heptapod:x.y.z` and
          `octobus/heptapod:latest` or `octobus/heptapod:x-y-latest`, and
          push the tags to Docker Hub, using
          the `push-release` script from heptapod/heptapod-docker>.

### Finalisations

- [ ] announce the release at least on Twitter and Mastodon
- [ ] publish the changesets in all repositories made during the process (don't
  forget Omnibus)
- [ ] Create group milestone for next point release, move all remaining issues
  bearing the milestone of this release to it.
- [ ] Close milestone for this release.


/label ~Release
